@@ -119,7 +119,7 @@ desktop_add_application (SpiDesktop *desktop,
   spi_init_any_nil (&e.any_data,
 		    e.source,
 		    Accessibility_ROLE_DESKTOP_FRAME,
-		    CORBA_string_dup (""));
+		    "");
 
   Accessibility_Registry_notifyEvent (BONOBO_OBJREF (registry),
 				      &e, &ev);
@@ -135,7 +135,7 @@ desktop_remove_application (SpiDesktop *desktop,
 {
   BonoboObject *registry = BONOBO_OBJECT (data);
   Accessibility_Event e;
-  Accessibility_Accessible a;
+  /* Accessibility_Accessible a; FIXME */
   CORBA_Environment ev;
   
   CORBA_exception_init (&ev);
@@ -144,16 +144,16 @@ desktop_remove_application (SpiDesktop *desktop,
   e.source = BONOBO_OBJREF (desktop);
   e.detail1 = index;
   e.detail2 = 0;
+  /* FIXME
   a = Accessibility_Accessible_getChildAtIndex (BONOBO_OBJREF (desktop), 
 						index, &ev);
-  /* FIXME
   spi_init_any_object (&e.any_data, a);
   */
   spi_init_any_nil (&e.any_data,
 		    e.source,
 		    Accessibility_ROLE_DESKTOP_FRAME,
-		    CORBA_string_dup (""));
-  Accessibility_Accessible_unref (a, &ev);
+		    "");
+  /* Accessibility_Accessible_unref (a, &ev); */
   Accessibility_Registry_notifyEvent (BONOBO_OBJREF (registry),
 				      &e, &ev);
   Accessibility_Desktop_unref (e.source, &ev);
@@ -718,6 +718,8 @@ registry_flush_event_queue (SpiRegistry       *registry,
     }
     CORBA_free ((void *)q_ctx->etype.event_name);
     CORBA_free ((void *)q_ctx->e_out.type);
+    if (q_ctx->e_out.any_data._type != TC_null) 
+	CORBA_free ((void *)q_ctx->e_out.any_data._value);
     g_free (q_ctx);
   }
   registry->is_queueing = FALSE;
@@ -848,6 +850,8 @@ registry_queue_event (SpiRegistry *registry, NotifyContext *ctx)
       bonobo_object_release_unref (q_ctx->source, NULL);
       CORBA_free ((void *)q_ctx->etype.event_name);
       CORBA_free ((void *)q_ctx->e_out.type);
+      if (q_ctx->e_out.any_data._type != TC_null) 
+	  CORBA_free ((void *)q_ctx->e_out.any_data._value);
       g_free (q_ctx);
       return TRUE; 
     }
